library(dplyr)
library(tidyr)
library(margins)
library(lubridate)
library(caret)
library(randomForest)
library(pROC)

library(xgboost)
# Test treatment effect

database_full <- database_full %>%
  filter(!is.na(Treatment_new)) %>%
  mutate(Dummy_Video_1 = case_when(Treatment_new == 1 ~ 1, TRUE ~ 0),
         Dummy_Video_2 = case_when(Treatment_new == 5 ~ 1, TRUE ~ 0),
         Dummy_no_info = case_when(Treatment_new == 3 ~ 1, TRUE~0),
         Dummy_Info_nv1 = case_when(Treatment_new == 2 ~1, TRUE~0),
         Dummy_Info_nv2 = case_when(Treatment_new == 4 ~1 , TRUE~0)) %>% 
  mutate(Engagement_ugs = groupTime1731 + groupTime1726 + groupTime1769 + groupTime1727 + groupTime1770 + groupTime1771 + groupTime1768 +
           groupTime1738)




data <- database_full %>%
  group_by(id) %>%
  dplyr::slice(1) %>%
  ungroup()
data <- data %>% 
  mutate(Choice_Treat = ifelse( Dummy_Video_2 == 1 | Dummy_Info_nv2 == 1, 1, 
                                ifelse(Dummy_no_info==1 ,0,NA))) 



table(data$Choice_Treat)  



logit_choice_treat<-glm(Choice_Treat ~  as.factor(Gender)+Z_Mean_NR+Age_mean + QFIncome +
                          as.factor(Education), data, family=binomial)
summary(logit_choice_treat)


logit_choice_treat_uni<-glm(Choice_Treat ~  as.factor(Gender)+Z_Mean_NR+Age_mean + QFIncome +
                              Uni_degree + Kids_Dummy + Engagement_ugs + UGS_visits, data, family=binomial)
summary(logit_choice_treat_uni)


logit_sig <- glm(Choice_Treat ~  Z_Mean_NR + Age_mean + QFIncome, data, family=binomial)

# Calculate marginal effects
marginal_effects <- margins(logit_choice_treat_uni)

# Display the marginal effects
summary(marginal_effects)               


cut_off <- 0.45


# Make predictions
data$probabilities <- logit_sig %>% predict(data, type = "response")
data$predicted.classes <- ifelse(data$probabilities  >= cut_off, 1, 0)
# Model accuracy
mean(data$predicted.classes == data$Choice_Treat, na.rm = T)







# Assuming your data is in a data frame called 'data'
set.seed(123)  # For reproducibility
data<-select(data, Choice_Treat, id, Age, Q02W123, Uni_degree, QFIncome,Z_Mean_NR, City, Screen,
             Uni_degree, Q02W123,Q04W123,Q05W123, Q08W123,Q09W123,Q10W123,Q11W3,Q12W123,Q13W23,Q14S01W123,Q14S02W23,
             Q14S03W123,Q14S04W123,Q14S05W123,Q14S06W23,Q14S07W3,Q14S08W2,Q14W23,
             Q15S01W3,Q15S02W3,Q16W3,Q17W13,Q18W123,Q19W3,C02W23,Q20W23,Q21W23,
             Q22S01W123,Q22S02W23,UGS_visits,Q24S01W123,
             Q24S02W123,Q24S03W123,Q24S04W23,Q24S05W123,Q25W23,Q26S01W123,Q26S02W123,
             Q26S03W23,Q26S04W123,Q26S05W123,Q26S06W123,Q26S07W23,Q26S08W23,Q26S99W23,
             Q27W123,Q30W23,Q31S01W23,Q31S02W23,Q31S03W23,Q31S04W23,
             Q31S05W23,Q31S06W23,Q31S08W23,Q32S01W23,Q32S02W23,Q32S03W23,
             Q33S01W3,Q33S02W3,Q33S03W3,Q33S04W3,Q33S05W3,Q33S06W3,Q33S07W3,Q33S99W3,
             Q34W23,Q35W23,Q36W23,Q37W23,Q38S01W3,Q38S02W3,Q38S03W3,Q38S04W3,Q38S05W3,
             Q38S06W3,Q38S07W3,Q38S08W3,Q38S09W3,Q38S10W3,Q38S11W3,Q38S12W3,Q38S13W3,
             Q38S14W3,Q38S15W3,Q38S16W3,Q38S17W3,Q38S18W3,Q38S19W3,Q38S20W3,Q38S21W3,
             V01W3,Q39S01W3,Q39S02W3,Q39S03W3,Q39S04W3,Q39S05W3,Q40W3
             ,Q45W123,Q46S01W3,Q46S02W3,Q46S03W3,Q46S04W3,
             Q47S01W23,Q47S02W3,Q47S03W3,Q47S04W3,Q47S05W3,Q47S06W3,Q47S07W3,Q47S08W3,
             Q47S09W3,Q48S01W3,Q48S02W3,Q48S03W3,Q48S04W3,Q48S05W3,Q49W23,Q50W123)
data <- data %>%
  select(where(~ all(!is.na(.)) & all(. != "")) | any_of("Choice_Treat"))
# Split the data into labeled and unlabeled sets
labeled_data <- filter(data, Choice_Treat==1| Choice_Treat==0)
unlabeled_data <- filter(data, is.na(Choice_Treat))
labeled_data_id<-labeled_data
labeled_data<-select(labeled_data,-id)
# Assuming the group information is in the column called 'Group'
labeled_data$Choice_Treat<- as.factor(labeled_data$Choice_Treat)
unlabeled_data$Choice_Treat<- as.factor(unlabeled_data$Choice_Treat)

trainIndex <- createDataPartition(labeled_data$Choice_Treat, p = 0.8, list = FALSE)
trainData <- labeled_data[trainIndex, ]
testData <- labeled_data[-trainIndex, ]






tuneGrid <- expand.grid(
  nrounds = c(300),
  max_depth = c(15),
  eta = c(0.05),
  gamma = c(0, 0.1),
  colsample_bytree = c(0.6, 0.8),     # Fraction of features to be used for each tree
  min_child_weight = c(1, 3, 5),      # Minimum sum of instance weight (hessian) needed in a child
  subsample = c(0.7, 0.8)             # Fraction of samples to be used for each tree
)


model3 <- train(Choice_Treat ~ ., 
                data = trainData, 
                method = "xgbTree", 
                tuneGrid = tuneGrid,
                trControl = trainControl(method = "cv", number = 5))


# Get variable importance
varImp(model3)



# Evaluate the model
predictions <- predict(model3, newdata = testData)
confusionMatrix(predictions, testData$Choice_Treat)
labeled_predictions <- predict(model3, newdata = labeled_data)
labeled_data$PredictedGroup <- labeled_predictions

table(labeled_data$Choice_Treat, labeled_data$PredictedGroup)

unlabeled_predictions <- predict(model3, newdata = unlabeled_data)
labeled_data_id$PredictedGroup <- labeled_predictions
data_prediction_labeled<-select(labeled_data_id, c("id", "PredictedGroup"))
saveRDS(data_prediction_labeled, "Data/predictions_labeled.RDS")

unlabeled_data$PredictedGroup <- unlabeled_predictions
data_prediction<-select(unlabeled_data, c("id", "PredictedGroup"))
saveRDS(data_prediction, "Data/predictions.RDS")

print(model3$bestTune)


table(data$predicted.classes ,data$Choice_Treat)

calculate_metrics <- function(confusion_matrix) {
  # Extract values from the confusion matrix
  TN <- confusion_matrix[1, 1]
  FP <- confusion_matrix[2, 1]
  FN <- confusion_matrix[1, 2]
  TP <- confusion_matrix[2, 2]
  
  # Calculate sensitivity
  sensitivity <- round(TP / (TP + FN), 2)
  
  # Calculate specificity
  specificity <- round(TN / (TN + FP), 2)
  
  # Return the results as a list
  return(list(sensitivity = sensitivity, specificity = specificity))
}

# Calculate metrics
metrics <- calculate_metrics(table(data$predicted.classes ,data$Choice_Treat))

# Print results
print(paste("Sensitivity:", metrics$sensitivity))
print(paste("Specificity:", metrics$specificity))
roc_obj <- roc(data$Choice_Treat, data$probabilities)
plot(roc_obj, main = "ROC Curve", col = "blue", lwd = 2)
auc_value <- auc(roc_obj)
best_coords <- coords(roc_obj, "best", best.method="youden")


cut_off <- best_coords$threshold